@@ -1,5 +1,5 @@
 package Validator::Custom::Result;
-use base 'Object::Simple::Base';
+use base 'Object::Simple';
 
 __PACKAGE__->attr(_errors  => sub { [] });
 
@@ -64,6 +64,8 @@ sub error {
     return;
 }
 
+1;
+
 =head1 Validator::Custom::Result
 
 =head1 NAME
